@@ -22,13 +22,12 @@
 #if !defined(LOGGING_H)
 #define LOGGING_H
 
-#include <qglobal.h> // For Q_ASSERT
+#include <QtGlobal> // For Q_ASSERT
+#include <QString> // For QString
 
-#ifdef ASSERT
-#undef ASSERT
-#endif
+#include "freemheg.h" // For MHLogError
 
-#define ASSERT(f)          Q_ASSERT(f)
+#define MHASSERT(f)          Q_ASSERT(f)
 
 extern int __mhlogoptions;
 extern void __mhlog(QString logtext);
