@@ -1,15 +1,15 @@
 // -*- Mode: c++ -*-
 // Copyright (c) 2003-2004, Daniel Thor Kristjansson
+#include "mythlogging.h"
 #include "pespacket.h"
 #include "mpegtables.h"
-#include "mythcontext.h"
 
 extern "C" {
 #include "mythconfig.h"
-#include "../libavcodec/avcodec.h"
-#include "../libavformat/avformat.h"
-#include "../libavutil/crc.h"
-#include "../libavutil/bswap.h"
+#include "libavcodec/avcodec.h"
+#include "libavformat/avformat.h"
+#include "libavutil/crc.h"
+#include "libavutil/bswap.h"
 }
 
 #include <vector>
@@ -23,20 +23,21 @@ bool PESPacket::AddTSPacket(const TSPacket* packet, bool &broken)
     broken = true;
     if (!tsheader()->PayloadStart())
     {
-        VERBOSE(VB_RECORD, "Error: We started a PES packet, "
-                "without a payloadStart!");
+        LOG(VB_RECORD, LOG_ERR,
+            "Error: We started a PES packet, without a payloadStart!");
         return true;
     }
     else if (!IsClone())
     {
-        VERBOSE(VB_RECORD, "Error: Must clone initially to use addPackets()");
+        LOG(VB_RECORD, LOG_ERR,
+            "Error: Must clone initially to use addPackets()");
         return false;
     }
 
     const int cc = packet->ContinuityCounter();
     const int ccExp = (_ccLast + 1) & 0xf;
-    uint payloadSize  = TSPacket::PAYLOAD_SIZE;
-    uint payloadStart = TSPacket::HEADER_SIZE;
+    uint payloadSize  = TSPacket::kPayloadSize;
+    uint payloadStart = TSPacket::kHeaderSize;
 
     // If the next TS has an offset, we need to strip it out.
     // The offset will be used when a new PESPacket is created.
@@ -72,9 +73,9 @@ bool PESPacket::AddTSPacket(const TSPacket* packet, bool &broken)
     }
     else
     {
-        VERBOSE(VB_RECORD, "AddTSPacket: Out of sync!!! "
-                "Need to wait for next payloadStart" +
-                QString(" PID: 0x%1, continuity counter: %2 (expected %3).")
+        LOG(VB_RECORD, LOG_ERR,
+            "AddTSPacket: Out of sync!!! Need to wait for next payloadStart" +
+            QString(" PID: 0x%1, continuity counter: %2 (expected %3).")
                 .arg(packet->PID(),0,16).arg(cc).arg(ccExp));
         return true;
     }
@@ -97,10 +98,10 @@ bool PESPacket::AddTSPacket(const TSPacket* packet, bool &broken)
     return false;
 }
 
-/** \fn PESPacket::WriteAsTSPackets(unsigned char*, uint&) const
- *  \brief Writes payload only PESPacket as series of TSPacket data
+/** \fn PESPacket::GetAsTSPackets(vector<TSPacket>&,uint) const
+ *  \brief Returns payload only PESPacket as series of TSPackets
  */
-uint PESPacket::WriteAsTSPackets(unsigned char *buf, uint &cc) const
+void PESPacket::GetAsTSPackets(vector<TSPacket> &output, uint cc) const
 {
 #define INCR_CC(_CC_) do { _CC_ = (_CC_ + 1) & 0xf; } while (0)
     uint last_byte_of_pesdata = Length() + 4 - 1;
@@ -108,14 +109,16 @@ uint PESPacket::WriteAsTSPackets(unsigned char *buf, uint &cc) const
 
     if (_pesdata == _fullbuffer)
     {
-        VERBOSE(VB_IMPORTANT, "WriteAsTSPackets _pesdata == _fullbuffer");
-        return 0;
+        LOG(VB_GENERAL, LOG_ERR, "WriteAsTSPackets _pesdata == _fullbuffer");
+        output.resize(0);
+        return;
     }
 
-    memcpy(buf, _fullbuffer, TSPacket::SIZE);
-    INCR_CC(cc);  buf[3] = buf[3] & 0xf0 | cc;
-    if (size <= TSPacket::SIZE)
-        return TSPacket::SIZE;
+    output.resize(1);
+    memcpy(output[0].data(), _fullbuffer, TSPacket::kSize);
+    output[0].data()[3] = (output[0].data()[3] & 0xf0) | cc;
+    if (size <= TSPacket::kSize)
+        return;
 
     TSHeader header;
     header.data()[1] = 0x00;
@@ -123,33 +126,19 @@ uint PESPacket::WriteAsTSPackets(unsigned char *buf, uint &cc) const
     header.data()[3] = 0x10; // adaptation field control == payload only
     header.SetPID(tsheader()->PID());
 
-    uint ret                  = TSPacket::SIZE;
-    unsigned char       *out  = buf + TSPacket::SIZE;
-    const unsigned char *data = _fullbuffer + TSPacket::SIZE;
-    size -= TSPacket::SIZE;
-    while (size > TSPacket::PAYLOAD_SIZE)
+    const unsigned char *data = _fullbuffer + TSPacket::kSize;
+    size -= TSPacket::kSize;
+    while (size > 0)
     {
         INCR_CC(cc);
         header.SetContinuityCounter(cc);
-        memcpy(out, header.data(), TSPacket::HEADER_SIZE);
-        memcpy(out + 4, data, TSPacket::PAYLOAD_SIZE);
-        data += TSPacket::PAYLOAD_SIZE;
-        size -= TSPacket::PAYLOAD_SIZE;
-        out  += TSPacket::SIZE;
-        ret  += TSPacket::SIZE;
+        output.resize(output.size()+1);
+        output[output.size()-1].InitHeader(header.data());
+        uint write_size = min(size, TSPacket::kPayloadSize);
+        output[output.size()-1].InitPayload(data, write_size);
+        data += write_size;
+        size -= write_size;
     }
-
-    if (size)
-    {
-        INCR_CC(cc);
-        header.SetContinuityCounter(cc);
-        memcpy(out, header.data(), TSPacket::HEADER_SIZE);
-        memcpy(out + 4, data, size);
-        memset(out + 4 + size, 0xff, TSPacket::PAYLOAD_SIZE - size);
-        ret += TSPacket::SIZE;
-    }
-
-    return ret;
 #undef INCR_CC
 }
 
@@ -157,8 +146,8 @@ uint PESPacket::CalcCRC(void) const
 {
     if (Length() < 1)
         return 0xffffffff;
-    return bswap_32(av_crc(av_crc04C11DB7, (uint32_t) -1,
-                           _pesdata, Length() - 1));
+    return av_bswap32(av_crc(av_crc_get_table(AV_CRC_32_IEEE), (uint32_t) -1,
+                             _pesdata, Length() - 1));
 }
 
 bool PESPacket::VerifyCRC(void) const
@@ -166,9 +155,9 @@ bool PESPacket::VerifyCRC(void) const
     bool ret = !HasCRC() || (CalcCRC() == CRC());
     if (!ret)
     {
-        VERBOSE(VB_SIPARSER,
-                QString("PESPacket: Failed CRC check 0x%1 != 0x%2 "
-                        "for StreamID = 0x%3")
+        LOG(VB_SIPARSER, LOG_INFO,
+            QString("PESPacket: Failed CRC check 0x%1 != 0x%2 "
+                    "for StreamID = 0x%3")
                 .arg(CRC(),0,16).arg(CalcCRC(),0,16).arg(StreamID(),0,16));
     }
     return ret;
@@ -267,7 +256,9 @@ static void return_188_block(unsigned char* ptr)
             free(*it);
         mem188.clear();
         free188.clear();
-        //cerr<<"freeing all 188 blocks"<<endl;
+#if 0
+        LOG(VB_GENERAL, LOG_DEBUG, "freeing all 188 blocks");
+#endif
     }
 }
 
@@ -301,21 +292,22 @@ static void return_4096_block(unsigned char* ptr)
     free4096.push_back(ptr);
 
 #if 0 // enable this to debug memory leaks
-        cerr<<alloc4096.size()<<" 4096 blocks remain"<<endl;
+        LOG(VB_GENERAL, LOG_DEBUG, QString("%1 4096 blocks remain")
+            .arg(alloc4096.size()));
         map<unsigned char*, bool>::iterator it;
         for (it = alloc4096.begin(); it != alloc4096.end(); ++it)
         {
             TSPacket *ts = (TSPacket*) it->first;
-            cerr<<QString("PES Packet: pid(0x%1)").arg(ts->PID(),0,16);
+            LGO(VB_GENERAL, LOG_DEBUG, QString("PES Packet: pid(0x%1)")
+                .arg(ts->PID(),0,16));
             if (ts->PID() == 0x1ffb)
             {
-                cerr<<QString(" tid(0x%1) ext(0x%2)")
+                LOG(VB_GENERAL, LOG_DEBUG, QString(" tid(0x%1) ext(0x%2)")
                     .arg(PSIPTable::View(*ts).TableID(),0,16)
-                    .arg(PSIPTable::View(*ts).TableIDExtension(),0,16);
+                    .arg(PSIPTable::View(*ts).TableIDExtension(),0,16));
             }
-            cerr<<endl;
         }
-#endif 
+#endif
 
     // free the allocator only if more than 1 block was used
     if (alloc4096.empty() && mem4096.size() > 1)
@@ -325,7 +317,9 @@ static void return_4096_block(unsigned char* ptr)
             free(*it);
         mem4096.clear();
         free4096.clear();
-        //cerr<<"freeing all 4096 blocks"<<endl;
+#if 0
+        LOG(VB_GENERAL, LOG_DEBUG, "freeing all 4096 blocks");
+#endif
     }
 }
 
@@ -334,20 +328,24 @@ static QMutex pes_alloc_mutex;
 unsigned char *pes_alloc(uint size)
 {
     QMutexLocker locker(&pes_alloc_mutex);
+#ifndef USING_VALGRIND
     if (size <= 188)
         return get_188_block();
     else if (size <= 4096)
         return get_4096_block();
+#endif // USING_VALGRIND
     return (unsigned char*) malloc(size);
 }
 
 void pes_free(unsigned char *ptr)
 {
     QMutexLocker locker(&pes_alloc_mutex);
+#ifndef USING_VALGRIND
     if (is_188_block(ptr))
         return_188_block(ptr);
     else if (is_4096_block(ptr))
         return_4096_block(ptr);
     else
+#endif // USING_VALGRIND
         free(ptr);
 }
