@@ -789,7 +789,7 @@ void RingBuffer::run(void)
         {
             // limit the read size
             if (readblocksize > totfree)
-                totfree = (int)(totfree / KB32) * KB32; // must be multiple of 32KB
+                totfree = (long long)(totfree / KB32) * KB32; // must be multiple of 32KB
             else
                 totfree = readblocksize;
 
